@@ -8,6 +8,7 @@ import (
 	"github.com/git-town/git-town/v12/src/cli/dialog/components"
 	"github.com/git-town/git-town/v12/src/config/configdomain"
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
+	"github.com/git-town/git-town/v12/src/gohacks/slice"
 	"golang.org/x/exp/maps"
 )
 
@@ -60,7 +61,13 @@ func (self SwitchModel) View() string {
 		return ""
 	}
 	s := strings.Builder{}
-	for i, branch := range self.Entries {
+	window := slice.Window(slice.WindowArgs{
+		ElementCount: len(self.Entries),
+		CursorPos:    self.Cursor,
+		WindowSize:   components.WindowSize,
+	})
+	for i := window.StartRow; i < window.EndRow; i++ {
+		branch := self.Entries[i]
 		switch {
 		case i == self.Cursor:
 			s.WriteString(self.Colors.Selection.Styled("> " + branch.String()))
@@ -82,6 +89,16 @@ func (self SwitchModel) View() string {
 	s.WriteString(self.Colors.Help.Styled("/"))
 	s.WriteString(self.Colors.HelpKey.Styled("j"))
 	s.WriteString(self.Colors.Help.Styled(" down   "))
+	// left
+	s.WriteString(self.Colors.HelpKey.Styled("←"))
+	s.WriteString(self.Colors.Help.Styled("/"))
+	s.WriteString(self.Colors.HelpKey.Styled("u"))
+	s.WriteString(self.Colors.Help.Styled(" 10 up   "))
+	// right
+	s.WriteString(self.Colors.HelpKey.Styled("→"))
+	s.WriteString(self.Colors.Help.Styled("/"))
+	s.WriteString(self.Colors.HelpKey.Styled("d"))
+	s.WriteString(self.Colors.Help.Styled(" 10 down   "))
 	// accept
 	s.WriteString(self.Colors.HelpKey.Styled("enter"))
 	s.WriteString(self.Colors.Help.Styled("/"))
