@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"fmt"
+	"os"
 
 	"github.com/git-town/git-town/v12/src/cli/dialog/components"
 	"github.com/git-town/git-town/v12/src/cli/flags"
@@ -66,7 +67,7 @@ func executeSync(all, dryRun, verbose bool) error {
 	if err != nil {
 		return err
 	}
-	config, initialBranchesSnapshot, initialStashSnapshot, exit, err := determineSyncConfig(all, repo, verbose)
+	config, initialBranchesSnapshot, initialStashSize, exit, err := determineSyncConfig(all, repo, verbose)
 	if err != nil || exit {
 		return err
 	}
@@ -102,7 +103,7 @@ func executeSync(all, dryRun, verbose bool) error {
 		RootDir:                 repo.RootDir,
 		InitialBranchesSnapshot: initialBranchesSnapshot,
 		InitialConfigSnapshot:   repo.ConfigSnapshot,
-		InitialStashSnapshot:    initialStashSnapshot,
+		InitialStashSize:        initialStashSize,
 	})
 }
 
@@ -118,8 +119,10 @@ type syncConfig struct {
 	shouldPushTags   bool
 }
 
-func determineSyncConfig(allFlag bool, repo *execute.OpenRepoResult, verbose bool) (*syncConfig, gitdomain.BranchesStatus, gitdomain.StashSize, bool, error) {
-	branchesSnapshot, stashSnapshot, dialogTestInputs, exit, err := execute.LoadRepoSnapshot(execute.LoadBranchesArgs{
+func determineSyncConfig(allFlag bool, repo *execute.OpenRepoResult, verbose bool) (*syncConfig, gitdomain.BranchesSnapshot, gitdomain.StashSize, bool, error) {
+	dialogTestInputs := components.LoadTestInputs(os.Environ())
+	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
+		DialogTestInputs:      dialogTestInputs,
 		FullConfig:            &repo.Runner.FullConfig,
 		Repo:                  repo,
 		Verbose:               verbose,
@@ -129,16 +132,16 @@ func determineSyncConfig(allFlag bool, repo *execute.OpenRepoResult, verbose boo
 		ValidateNoOpenChanges: false,
 	})
 	if err != nil || exit {
-		return nil, branchesSnapshot, stashSnapshot, exit, err
+		return nil, branchesSnapshot, stashSize, exit, err
 	}
 	previousBranch := repo.Runner.Backend.PreviouslyCheckedOutBranch()
 	repoStatus, err := repo.Runner.Backend.RepoStatus()
 	if err != nil {
-		return nil, branchesSnapshot, stashSnapshot, false, err
+		return nil, branchesSnapshot, stashSize, false, err
 	}
 	remotes, err := repo.Runner.Backend.Remotes()
 	if err != nil {
-		return nil, branchesSnapshot, stashSnapshot, false, err
+		return nil, branchesSnapshot, stashSize, false, err
 	}
 	var branchNamesToSync gitdomain.LocalBranchNames
 	var shouldPushTags bool
@@ -151,7 +154,7 @@ func determineSyncConfig(allFlag bool, repo *execute.OpenRepoResult, verbose boo
 			Runner:           repo.Runner,
 		})
 		if err != nil {
-			return nil, branchesSnapshot, stashSnapshot, false, err
+			return nil, branchesSnapshot, stashSize, false, err
 		}
 		branchNamesToSync = localBranches.Names()
 		shouldPushTags = true
@@ -164,7 +167,7 @@ func determineSyncConfig(allFlag bool, repo *execute.OpenRepoResult, verbose boo
 			Runner:           repo.Runner,
 		})
 		if err != nil {
-			return nil, branchesSnapshot, stashSnapshot, false, err
+			return nil, branchesSnapshot, stashSize, false, err
 		}
 		branchNamesToSync = gitdomain.LocalBranchNames{branchesSnapshot.Active}
 		shouldPushTags = !repo.Runner.IsFeatureBranch(branchesSnapshot.Active)
@@ -181,5 +184,5 @@ func determineSyncConfig(allFlag bool, repo *execute.OpenRepoResult, verbose boo
 		previousBranch:   previousBranch,
 		remotes:          remotes,
 		shouldPushTags:   shouldPushTags,
-	}, branchesSnapshot, stashSnapshot, false, err
+	}, branchesSnapshot, stashSize, false, err
 }
