@@ -1,8 +1,6 @@
 package execute
 
 import (
-	"os"
-
 	"github.com/git-town/git-town/v12/src/cli/dialog/components"
 	"github.com/git-town/git-town/v12/src/config/configdomain"
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
@@ -10,76 +8,76 @@ import (
 )
 
 // LoadRepoSnapshot loads the initial snapshot of the Git repo.
-func LoadRepoSnapshot(args LoadBranchesArgs) (gitdomain.BranchesStatus, gitdomain.StashSize, components.TestInputs, bool, error) {
-	var branchesSnapshot gitdomain.BranchesStatus
-	dialogInputs := components.LoadTestInputs(os.Environ())
+func LoadRepoSnapshot(args LoadRepoSnapshotArgs) (gitdomain.BranchesSnapshot, gitdomain.StashSize, bool, error) {
+	var branchesSnapshot gitdomain.BranchesSnapshot
 	var err error
-	stashSnapshot, err := args.Repo.Runner.Backend.StashSize()
+	stashSize, err := args.Repo.Runner.Backend.StashSize()
 	if err != nil {
-		return gitdomain.EmptyBranchesSnapshot(), stashSnapshot, dialogInputs, false, err
+		return gitdomain.EmptyBranchesSnapshot(), stashSize, false, err
 	}
 	if args.HandleUnfinishedState {
 		branchesSnapshot, err = args.Repo.Runner.Backend.BranchesSnapshot()
 		if err != nil {
-			return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+			return branchesSnapshot, stashSize, false, err
 		}
 		exit, err := validate.HandleUnfinishedState(validate.UnfinishedStateArgs{
 			Connector:               nil,
-			DialogTestInputs:        dialogInputs,
+			DialogTestInputs:        args.DialogTestInputs,
 			Verbose:                 args.Verbose,
 			InitialBranchesSnapshot: branchesSnapshot,
 			InitialConfigSnapshot:   args.Repo.ConfigSnapshot,
-			InitialStashSnapshot:    stashSnapshot,
+			InitialStashSize:        stashSize,
 			Lineage:                 args.Lineage,
 			PushHook:                args.PushHook,
 			RootDir:                 args.Repo.RootDir,
 			Run:                     args.Repo.Runner,
 		})
 		if err != nil || exit {
-			return branchesSnapshot, stashSnapshot, dialogInputs, exit, err
+			return branchesSnapshot, stashSize, exit, err
 		}
 	}
 	if args.ValidateNoOpenChanges {
 		repoStatus, err := args.Repo.Runner.Backend.RepoStatus()
 		if err != nil {
-			return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+			return branchesSnapshot, stashSize, false, err
 		}
 		err = validate.NoOpenChanges(repoStatus.OpenChanges)
 		if err != nil {
-			return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+			return branchesSnapshot, stashSize, false, err
 		}
 	}
 	if args.Fetch {
 		var remotes gitdomain.Remotes
 		remotes, err := args.Repo.Runner.Backend.Remotes()
 		if err != nil {
-			return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+			return branchesSnapshot, stashSize, false, err
 		}
 		if remotes.HasOrigin() && !args.Repo.IsOffline.Bool() {
 			err = args.Repo.Runner.Frontend.Fetch()
 			if err != nil {
-				return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+				return branchesSnapshot, stashSize, false, err
 			}
 		}
 		branchesSnapshot, err = args.Repo.Runner.Backend.BranchesSnapshot()
 		if err != nil {
-			return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+			return branchesSnapshot, stashSize, false, err
 		}
 	}
 	if branchesSnapshot.IsEmpty() {
 		branchesSnapshot, err = args.Repo.Runner.Backend.BranchesSnapshot()
 		if err != nil {
-			return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+			return branchesSnapshot, stashSize, false, err
 		}
 	}
 	if args.ValidateIsConfigured {
-		err = validate.IsConfigured(&args.Repo.Runner.Backend, args.FullConfig, branchesSnapshot.Branches.LocalBranches().Names(), &dialogInputs)
+		err = validate.IsConfigured(&args.Repo.Runner.Backend, args.FullConfig, branchesSnapshot.Branches.LocalBranches().Names(), &args.DialogTestInputs)
 	}
-	return branchesSnapshot, stashSnapshot, dialogInputs, false, err
+	return branchesSnapshot, stashSize, false, err
 }
 
-type LoadBranchesArgs struct {
+type LoadRepoSnapshotArgs struct {
 	*configdomain.FullConfig
+	DialogTestInputs      components.TestInputs
 	Fetch                 bool
 	HandleUnfinishedState bool
 	Repo                  *OpenRepoResult
