@@ -19,7 +19,7 @@ func CreateUndoProgram(args CreateUndoProgramArgs) (program.Program, error) {
 	if err != nil {
 		return program.Program{}, err
 	}
-	undoStashProgram, err := undostash.DetermineUndoStashProgram(args.InitialStashSnapshot, &args.Run.Backend)
+	undoStashProgram, err := undostash.DetermineUndoStashProgram(args.InitialStashSize, &args.Run.Backend)
 	if err != nil {
 		return program.Program{}, err
 	}
@@ -30,9 +30,9 @@ func CreateUndoProgram(args CreateUndoProgramArgs) (program.Program, error) {
 
 type CreateUndoProgramArgs struct {
 	DryRun                   bool
-	InitialBranchesSnapshot  gitdomain.BranchesStatus
+	InitialBranchesSnapshot  gitdomain.BranchesSnapshot
 	InitialConfigSnapshot    undoconfig.ConfigSnapshot
-	InitialStashSnapshot     gitdomain.StashSize
+	InitialStashSize         gitdomain.StashSize
 	NoPushHook               configdomain.NoPushHook
 	Run                      *git.ProdRunner
 	UndoablePerennialCommits []gitdomain.SHA
