@@ -23,7 +23,7 @@ func HandleUnfinishedState(args UnfinishedStateArgs) (quit bool, err error) {
 	if err != nil {
 		return false, fmt.Errorf(messages.RunstateLoadProblem, err)
 	}
-	if runState == nil || !runState.IsUnfinished() {
+	if runState == nil || runState.IsFinished() {
 		return false, nil
 	}
 	response, aborted, err := dialog.AskHowToHandleUnfinishedRunState(
@@ -57,9 +57,9 @@ func HandleUnfinishedState(args UnfinishedStateArgs) (quit bool, err error) {
 type UnfinishedStateArgs struct {
 	Connector               hostingdomain.Connector
 	DialogTestInputs        components.TestInputs
-	InitialBranchesSnapshot gitdomain.BranchesStatus
+	InitialBranchesSnapshot gitdomain.BranchesSnapshot
 	InitialConfigSnapshot   undoconfig.ConfigSnapshot
-	InitialStashSnapshot    gitdomain.StashSize
+	InitialStashSize        gitdomain.StashSize
 	Lineage                 configdomain.Lineage
 	PushHook                configdomain.PushHook
 	RootDir                 gitdomain.RepoRootDir
@@ -75,7 +75,7 @@ func abortRunstate(runState *runstate.RunState, args UnfinishedStateArgs) (bool,
 		DialogTestInputs:        &args.DialogTestInputs,
 		InitialBranchesSnapshot: args.InitialBranchesSnapshot,
 		InitialConfigSnapshot:   args.InitialConfigSnapshot,
-		InitialStashSnapshot:    args.InitialStashSnapshot,
+		InitialStashSize:        args.InitialStashSize,
 		RootDir:                 args.RootDir,
 		Run:                     args.Run,
 		RunState:                &abortRunState,
@@ -97,7 +97,7 @@ func continueRunstate(runState *runstate.RunState, args UnfinishedStateArgs) (bo
 		DialogTestInputs:        &args.DialogTestInputs,
 		InitialBranchesSnapshot: args.InitialBranchesSnapshot,
 		InitialConfigSnapshot:   args.InitialConfigSnapshot,
-		InitialStashSnapshot:    args.InitialStashSnapshot,
+		InitialStashSize:        args.InitialStashSize,
 		RootDir:                 args.RootDir,
 		Run:                     args.Run,
 		RunState:                runState,
@@ -119,7 +119,7 @@ func skipRunstate(runState *runstate.RunState, args UnfinishedStateArgs) (bool,
 		Verbose:                 args.Verbose,
 		InitialBranchesSnapshot: args.InitialBranchesSnapshot,
 		InitialConfigSnapshot:   args.InitialConfigSnapshot,
-		InitialStashSnapshot:    args.InitialStashSnapshot,
+		InitialStashSize:        args.InitialStashSize,
 		RootDir:                 args.RootDir,
 		Run:                     args.Run,
 		RunState:                &skipRunState,
