@@ -38,7 +38,7 @@ func (self *RunState) AddPushBranchAfterCurrentBranchProgram(backend *git.Backen
 	popped := program.Program{}
 	for {
 		nextOpcode := self.RunProgram.Peek()
-		if !shared.IsCheckoutOpcode(nextOpcode) {
+		if !shared.IsEndOfBranchProgramOpcode(nextOpcode) {
 			popped.Add(self.RunProgram.Pop())
 		} else {
 			currentBranch, err := backend.CurrentBranch()
@@ -77,15 +77,18 @@ func (self *RunState) CreateSkipRunState() RunState {
 		InitialActiveBranch: self.InitialActiveBranch,
 		RunProgram:          self.AbortProgram,
 	}
+	// undo the operations done on the current branch so far
+	// by copying the respective undo-opcodes into the runprogram
 	for _, opcode := range self.UndoProgram {
 		if shared.IsCheckoutOpcode(opcode) {
 			break
 		}
 		result.RunProgram.Add(opcode)
 	}
+	// skip the remaining run-opcodes for this branch
 	skipping := true
 	for _, opcode := range self.RunProgram {
-		if shared.IsCheckoutOpcode(opcode) {
+		if shared.IsEndOfBranchProgramOpcode(opcode) {
 			skipping = false
 		}
 		if !skipping {
@@ -125,9 +128,9 @@ func (self *RunState) HasUndoProgram() bool {
 	return !self.UndoProgram.IsEmpty()
 }
 
-// IsUnfinished returns whether or not the run state is unfinished.
-func (self *RunState) IsUnfinished() bool {
-	return self.UnfinishedDetails != nil
+// IsFinished returns whether or not the run state is unfinished.
+func (self *RunState) IsFinished() bool {
+	return self.UnfinishedDetails == nil
 }
 
 // MarkAsFinished updates the run state to be marked as finished.
@@ -160,7 +163,7 @@ func (self *RunState) RegisterUndoablePerennialCommit(commit gitdomain.SHA) {
 func (self *RunState) SkipCurrentBranchProgram() {
 	for {
 		opcode := self.RunProgram.Peek()
-		if shared.IsCheckoutOpcode(opcode) {
+		if shared.IsEndOfBranchProgramOpcode(opcode) {
 			break
 		}
 		self.RunProgram.Pop()
