@@ -80,6 +80,7 @@ func TestLoadSave(t *testing.T) {
 					Branch: gitdomain.NewRemoteBranchName("origin/branch"),
 				},
 				&opcode.DiscardOpenChanges{},
+				&opcode.EndOfBranchProgram{},
 				&opcode.EnsureHasShippableChanges{
 					Branch: gitdomain.NewLocalBranchName("branch"),
 					Parent: gitdomain.NewLocalBranchName("parent"),
@@ -268,6 +269,10 @@ func TestLoadSave(t *testing.T) {
       "data": {},
       "type": "DiscardOpenChanges"
     },
+    {
+      "data": {},
+      "type": "EndOfBranchProgram"
+    },
     {
       "data": {
         "Branch": "branch",
